package com.lightinit.hsdatashow.mapper;

import com.lightinit.hsdatashow.entity.GarbageCan;
import com.lightinit.hsdatashow.entity.GarbageCanExample;
import java.util.List;
import org.apache.ibatis.annotations.Param;

public interface GarbageCanMapper {
    long countByExample(GarbageCanExample example);

    int deleteByExample(GarbageCanExample example);

    int deleteByPrimaryKey(Long id);

    int insert(GarbageCan record);

    int insertSelective(GarbageCan record);

    List<GarbageCan> selectByExample(GarbageCanExample example);

    GarbageCan selectByPrimaryKey(Long id);

    int updateByExampleSelective(@Param("record") GarbageCan record, @Param("example") GarbageCanExample example);

    int updateByExample(@Param("record") GarbageCan record, @Param("example") GarbageCanExample example);

    int updateByPrimaryKeySelective(GarbageCan record);

    int updateByPrimaryKey(GarbageCan record);

    List<GarbageCan> selectList();

    GarbageCan selectByName(String name);

    List<GarbageCan> selectByparentId(Long id);

    List<GarbageCan> selectList2();

    List<GarbageCan> selectList3();

    List<GarbageCan> getTop();
    List<GarbageCan> getBottom();
}